@@ -9,9 +9,8 @@
 package WebService::HashiCorp::Vault::Sys;
 
 use Moo;
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 use namespace::clean;
-
 extends 'WebService::HashiCorp::Vault::Base';
 
 has '+mount' => ( is => 'ro', default => 'sys' );
@@ -27,6 +26,22 @@ sub audit {
     return $self->get( $self->_mkuri('audit') )
 }
 
+
+sub audit_put {
+    my ( $self, $name, %params ) = @_;
+    return $self->_sys_put( 'audit', $name, %params );
+
+}
+
+
+
+sub audit_del {
+    my ( $self, $name ) = @_;
+    return $self->_sys_del( 'audit', $name );
+}
+
+
+
 #            <a href="/api/system/audit-hash.html"><tt>/sys/audit-hash</tt></a>
 #
 #
@@ -35,9 +50,40 @@ sub audit {
 
 sub auth {
     my $self = shift;
-    return $self->get( $self->_mkuri('auth') )
+    return $self->get( $self->_mkuri('auth') );
 }
 
+
+sub auth_put {
+    my ( $self, $name, %params ) = @_;
+    return $self->_sys_put( 'audit', $name, %params );
+
+}
+
+
+sub auth_del {
+    my ( $self, $name ) = @_;
+    return $self->_sys_del( 'audit', $name );
+}
+
+#
+# Internal functions to do the put/del actions.
+#
+sub _sys_put {
+    my ( $self, $sys_type, $name, %params ) = @_;
+    my $uri = join '/', $self->_mkuri($sys_type), $name;
+    return $self->post( $uri, \%params );
+
+}
+
+sub _sys_del {
+    my ( $self, $sys_type, $name ) = @_;
+    my $uri = join '/', $self->_mkuri($sys_type), $name;
+    return $self->delete( $uri );
+
+}
+
+
 #            <a href="/api/system/capabilities.html"><tt>/sys/capabilities</tt></a>
 #
 #
@@ -52,7 +98,6 @@ sub auth {
 #
 #            <a href="/api/system/generate-root.html"><tt>/sys/generate-root</tt></a>
 
-
 sub generate_root {
     my $self = shift;
     return $self->get( $self->_mkuri('generate-root') )
@@ -164,7 +209,7 @@ WebService::HashiCorp::Vault::Sys - Perl API for HashiCorp's Vault (System)
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -189,7 +234,18 @@ Returns the 'audit' of the vault from API location I</sys/audit>
 
 The result is a hash reference
 
-TODO: implement PUT and DELETE audit with this function
+=head2 audit_put
+
+ my $audit = $sys->audit($audit_device, %options);
+
+Add an audit device.
+Returns true (1) if it succeeds, false (0) other wise.
+
+=head2 audit_del
+
+ my $audit = $sys->auth_del($audit_device);
+
+Delete an audit device.
 
 =head2 auth
 
@@ -199,7 +255,18 @@ Returns the 'auth' of the vault from API location I</sys/auth>
 
 The result is a hash reference
 
-TODO: implement POST and DELETE auth with this function
+=head2 auth_put
+
+ my $audit = $sys->auth($auth_method, %options);
+
+Add an Auth method
+Returns true (1) if it succeeds, false (0) other wise.
+
+=head2 auth_del
+
+ my $audit = $sys->auth_del($audit_device);
+
+Delete an auth method.
 
 =head2 generate_root
 
@@ -301,7 +368,7 @@ Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Dean Hamstad.
+This software is copyright (c) 2022 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
